@@ -788,7 +788,7 @@ calc_reallen(struct sk_buff *skb, const struct net_device *ndev)
 	**
 	**    since packet assembly/disassembly is done by the IP layer
 	**    (we get an input packet that has been assembled already and
-	**    an output packet that still has to be assembled), additional
+	**    an output packet that still has to be disassembled), additional
 	**    IP headers/interface headers and interface headers have
 	**    to be calculated for packets that are larger than the mtu
 	**
@@ -984,7 +984,7 @@ get_taskinfo(pid_t id, char type)
 
 /*
 ** garbage collector that removes:
-** - exited tasks that are not by user mode programs
+** - exited tasks that are no longer used by user mode programs
 ** - sockinfo's that are not used any more
 ** - taskinfo's that do not exist any more
 **
@@ -1675,6 +1675,34 @@ static int netatop_thread(void *dummy)
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 13, 0)
+static int __net_init netatop_nf_register(struct net *net)
+{
+	int err;
+
+	err = nf_register_net_hooks(net, &hookin_ipv4,  1);
+	if (err)
+		return err;
+
+	err = nf_register_net_hooks(net, &hookout_ipv4, 1);
+        if (err)
+		nf_unregister_net_hooks(net, &hookin_ipv4,  1);		
+
+	return err;
+}
+
+static void __net_exit netatop_nf_unregister(struct net *net)
+{
+        nf_unregister_net_hooks(net, &hookin_ipv4,  1);
+        nf_unregister_net_hooks(net, &hookout_ipv4, 1);
+}
+
+static struct pernet_operations netatop_net_ops = {
+        .init = netatop_nf_register,
+        .exit = netatop_nf_unregister,
+};
+#endif
+
 /*
 ** called when module loaded
 */
@@ -1738,7 +1766,7 @@ init_module()
 	}
 
 	/*
-	** prepare hooks and register
+	** prepare hooks for input and output packets
 	*/
 	hookin_ipv4.hooknum	= NF_IP_LOCAL_IN;	// input packs
 	hookin_ipv4.hook	= ipv4_hookin;		// func to call
@@ -1750,8 +1778,14 @@ init_module()
 	hookout_ipv4.pf		= PF_INET;		// IPV4 packets
 	hookout_ipv4.priority	= NF_IP_PRI_FIRST;	// highest prio
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 13, 0)
+	i = register_pernet_subsys(&netatop_net_ops);
+	if (i)
+		return i;
+#else
 	nf_register_hook(&hookin_ipv4);			// register hook
 	nf_register_hook(&hookout_ipv4);		// register hook
+#endif
 
 	/*
 	** create a /proc-entry to produce status-info on request
@@ -1780,8 +1814,12 @@ cleanup_module()
 	/*
  	** unregister netfilter hooks and other miscellaneous stuff
 	*/
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 13, 0)
+	unregister_pernet_subsys(&netatop_net_ops);
+#else
 	nf_unregister_hook(&hookin_ipv4);
 	nf_unregister_hook(&hookout_ipv4);
+#endif
 
 	remove_proc_entry("netatop", NULL);
 
